## JavaScript Object Notation

Introduction from *w3schools*:
- [https://www.w3schools.com/js/js_json_intro.asp](https://www.w3schools.com/js/js_json_intro.asp)

## JSON Schema

Official Documentation:
- [https://json-schema.org](https://json-schema.org)
